Description Usage Arguments Details Examples
The browser may be directed to a specific year, survey, or table.
1 | browseNHANES(year = NULL, data_group = NULL, nh_table = NULL)
|
year |
The year in yyyy format where 1999 <= yyyy <= 2016. |
data_group |
The type of survey (DEMOGRAPHICS, DIETARY, EXAMINATION, LABORATORY, QUESTIONNAIRE). Abbreviated terms may also be used: (DEMO, DIET, EXAM, LAB, Q). |
nh_table |
The name of an NHANES table. |
browseNHANES will open a web browser to the specified NHANES site.
1 2 3 4 5 | browseNHANES() # Defaults to the main data sets page
browseNHANES(2005) # The main page for the specified survey year
browseNHANES(2009, 'EXAM') # Page for the specified year and survey group
browseNHANES(nh_table = 'VIX_D') # Page for a specific table
browseNHANES(nh_table = 'DXA') # DXA main page
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.