Description Usage Arguments Details Value Examples
DXA data were acquired from 1999-2006.
1 |
year |
The year of the data to import, where 1999<=year<=2006. |
suppl |
If TRUE then retrieve the supplemental data (default=FALSE). |
destfile |
The name of a destination file. If NULL then the data are imported into the R environment but no file is created. |
Provide destfile in order to write the data to file. If destfile is not provided then the data will be imported into the R environment.
By default the table is returned as a data frame. When downloading to file, the return argument is the integer code from download.file where 0 means success and non-zero indicates failure to download.
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.