Description Usage Arguments Details Value Examples
Returns a list of table names that match a specified pattern.
1 2 3 4 5 6 7 8 |
pattern |
Pattern of table names to match |
ystart |
Four digit year of first survey included in search, where ystart >= 1999. |
ystop |
Four digit year of final survey included in search, where ystop >= ystart. |
includerdc |
If TRUE then RDC only tables are included (default=FALSE). |
nchar |
Truncates the variable description to a max length of nchar. |
details |
If TRUE then complete table information from the comprehensive data list is returned (default=FALSE). |
Searches the Doc File field in the NHANES Comprehensive Data List (see https://wwwn.cdc.gov/nchs/nhanes/search/DataPage.aspx) for tables that match a given name pattern. Only a single pattern may be entered.
A list of table names that match the pattern.
1 2 | nhanesSearchTableNames('BMX')
nhanesSearchTableNames('HPVS', includerdc=TRUE, details=TRUE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.