Description Usage Arguments Details Examples
Returns a list of table names that contain the variable
1 2 3 4 5 6 7 8 |
varname |
Name of variable to match. |
ystart |
Four digit year of first survey included in search, where ystart >= 1999. |
ystop |
Four digit year of final survey included in search, where ystop >= ystart. |
includerdc |
If TRUE then RDC only tables are included in list (default=FALSE). |
nchar |
Truncates the variable description to a max length of nchar. |
namesonly |
If TRUE then only the table names are returned (default=TRUE). |
The NHANES Comprehensive Variable List is scanned to find all data tables that contain the given variable name. Only a single variable name may be entered, and only exact matches will be found.
1 2 | nhanesSearchVarName('BMXLEG')
nhanesSearchVarName('BMXHEAD', ystart=2003)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.