Description Usage Arguments Details Value Examples
Enables quick display of table variables and their definitions.
1 2 3 4 5 6 7 | nhanesTableVars(
data_group,
nh_table,
details = FALSE,
nchar = 100,
namesonly = FALSE
)
|
data_group |
The type of survey (DEMOGRAPHICS, DIETARY, EXAMINATION, LABORATORY, QUESTIONNAIRE). Abbreviated terms may also be used: (DEMO, DIET, EXAM, LAB, Q). |
nh_table |
The name of the specific table to retrieve. |
details |
If TRUE then all columns in the variable description are returned (default=FALSE). |
nchar |
The number of characters in the Variable Description to print. Values are limited to 0<=nchar<=128. This is used to enhance readability, cause variable descriptions can be very long. |
namesonly |
If TRUE then only the variable names are returned (default=FALSE). |
Data are retrieved via web scraping using html wrappers from package rvest. Each data table contains multiple, sometimes more than 100, fields. It is helpful to list the field descriptions to ascertain quickly if a data table is of interest.
The names of the tables in the specified survey group
1 2 3 | nhanesTableVars('LAB', 'CBC_E')
nhanesTableVars('EXAM', 'OHX_E', details=TRUE, nchar=50)
nhanesTableVars('DEMO', 'DEMO_F', namesonly = TRUE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.