Description Usage Arguments Details Value Examples
Enables quick display of all available tables in the survey group.
1 2 3 4 5 6 7 8 | nhanesTables(
data_group,
year,
nchar = 100,
details = FALSE,
namesonly = FALSE,
includerdc = FALSE
)
|
data_group |
The type of survey (DEMOGRAPHICS, DIETARY, EXAMINATION, LABORATORY, QUESTIONNAIRE). Abbreviated terms may also be used: (DEMO, DIET, EXAM, LAB, Q). |
year |
The year in yyyy format where 1999 <= yyyy <= 2014. |
nchar |
Truncates the table description to a max length of nchar. |
details |
If TRUE then a more detailed description of the tables is returned (default=FALSE). |
namesonly |
If TRUE then only the table names are returned (default=FALSE). |
includerdc |
If TRUE then RDC only tables are included in list (default=FALSE). |
Data are retrieved via web scraping using html wrappers from package rvest. It is often useful to display the table names in an NHANES survey. In effect this is a convenient way to browse the available NHANES tables.
The names of the tables in the specified survey group.
1 2 3 | nhanesTables('EXAM', 2007)
nhanesTables('LAB', 2009, details=TRUE, includerdc=TRUE)
nhanesTables('Q', 2005, namesonly=TRUE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.