Description Usage Arguments Details Value Examples
Returns code translations for categorical variables, which appear in most NHANES tables.
1 2 3 4 5 6 7 8 9 |
nh_table |
The name of the NHANES table to retrieve. |
colnames |
The names of the columns to translate. |
data |
If a data frame is passed, then code translation will be applied directly to the data frame. |
nchar |
Applies only when data is defined. Code translations can be very long. |
mincategories |
The minimum number of categories needed for code translations to be applied to the data (default=2). |
details |
If TRUE then all available table translation information is displayed (default=FALSE). |
dxa |
If TRUE then the 2005-2006 DXA translation table will be used (default=FALSE). |
Code translation tables are retrieved via webscraping using rvest. Many of the NHANES data tables have encoded values. E.g. 1 = 'Male', 2 = 'Female'. Thus it is often helpful to view the code translations and perhaps insert the translated values in a data frame. Note that Hmisc supports "labelled" fields. When a translation is applied directly to a column in a data frame, the column class is first converted to 'factor' and then the coded values are replaced with the code translations.
The code translation table (or translated data frame when data is defined).
1 2 3 | nhanesTranslate('DEMO_B', c('DMDBORN','DMDCITZN'))
nhanesTranslate('BPX_F', 'BPACSZ', details=TRUE)
nhanesTranslate('BPX_F', 'BPACSZ', data=nhanes('BPX_F'))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.